@@ -14,8 +14,8 @@ from jinja2 import Environment
 from cloudinary_cli.defaults import logger, TEMPLATE_FOLDER
 
 not_callable = ('is_appengine_sandbox', 'call_tags_api', 'call_context_api', 'call_cacheable_api', 'call_api',
-                'call_metadata_api', 'call_json_api', 'text', 'only', 'transformation_string'
-                'account_config', 'reset_config', 'upload_large_part')
+                'call_metadata_api', 'call_json_api', 'only', 'transformation_string'
+                'account_config', 'reset_config', 'upload_large_part', 'upload_image', 'upload_resource')
 
 BLOCK_SIZE = 65536
 
@@ -80,7 +80,8 @@ def parse_option_value(value):
         value = json.loads(value)
     except Exception:
         pass
-    if isinstance(value, int):
+    # serialize 0 to "0" string, otherwise it will be omitted (counted as False)
+    if isinstance(value, int) and not value:
         value = str(value)
     return value
 
